searchData={"items":[{"type":"module","title":"Buffy","doc":"Buffy is broken down into different modules depending on how you want to\nhandle your function calling.","ref":"Buffy.html"},{"type":"module","title":"Throttle - Buffy","doc":"The `Buffy.Throttle` module will wait for a specified amount of time before\ninvoking the function. If the function is called again before the time has\nelapsed, it's a no-op. Once the timer has expired, the function will be called,\nand any subsequent calls will start a new timer.\n\n```text\ncall     call   call               call           call\n | call   | call | call             | call         |\n |  |     |  |   |  |               |  |           |\n┌─────────┐  ┌─────────┐            ┌─────────┐    ┌─────────┐\n│ Timer 1 │  │ Timer 2 │            │ Timer 3 │    │ Timer 4 │\n└─────────|  └─────────┘            └─────────┘    └─────────┘\n          |            |                      |              |\n          |            |                      |    Forth function invocation\n          |            |            Third function invocation\n          | Second function invocation\nFirst function invocation\n```","ref":"Buffy.html#module-throttle"},{"type":"module","title":"Buffy.Application","doc":"The Buffy supervisor responsible for starting the default\n`Registry` and `DynamicSupervisor`.","ref":"Buffy.Application.html"},{"type":"behaviour","title":"Buffy.Throttle","doc":"The `Buffy.Throttle` module will wait for a specified amount of time before\ninvoking the function. If the function is called again before the time has\nelapsed, it's a no-op. Once the timer has expired, the function will be called,\nand any subsequent calls will start a new timer.\n\n```text\ncall     call   call               call           call\n | call   | call | call             | call         |\n |  |     |  |   |  |               |  |           |\n┌─────────┐  ┌─────────┐            ┌─────────┐    ┌─────────┐\n│ Timer 1 │  │ Timer 2 │            │ Timer 3 │    │ Timer 4 │\n└─────────|  └─────────┘            └─────────┘    └─────────┘\n          |            |                      |              |\n          |            |                      |    Forth function invocation\n          |            |            Third function invocation\n          | Second function invocation\nFirst function invocation\n```","ref":"Buffy.Throttle.html"},{"type":"behaviour","title":"Example Usage - Buffy.Throttle","doc":"You'll first need to create a module that will be used to throttle.\n\n    defmodule MyTask do\n      use Buffy.Throttle,\n        throttle: :timer.minutes(2)\n\n      def handle_throttle(args) do\n        # Do something with args\n      end\n    end\n\nNext, you can use the `throttle/1` function with the registered module.\n\n    iex> MyTask.throttle(args)\n    :ok","ref":"Buffy.Throttle.html#module-example-usage"},{"type":"behaviour","title":"Options - Buffy.Throttle","doc":"- `:registry_module` (`atom`) - Optional. A module that implements the `Registry` behaviour. If you are running in a distributed instance, you can set this value to `Horde.Registry`. Defaults to `Registry`.\n\n  - `:registry_name` (`atom`) - Optional. The name of the registry to use. Defaults to the built in Buffy registry, but if you are running in a distributed instance you can set this value to a named `Horde.Registry` process. Defaults to `Buffy.Registry`.\n\n  - `:restart` (`:permanent` | `:temporary` | `:transient`) - Optional. The restart strategy to use for the GenServer. Defaults to `:temporary`.\n\n  - `:supervisor_module` (`atom`) - Optional. A module that implements the `DynamicSupervisor` behaviour. If you are running in a distributed instance, you can set this value to `Horde.DynamicSupervisor`. Defaults to `DynamicSupervisor`.\n\n  - `:supervisor_name` (`atom`) - Optional. The name of the dynamic supervisor to use. Defaults to the built in Buffy dynamic supervisor, but if you are running in a distributed instance you can set this value to a named `Horde.DynamicSupervisor` process. Defaults to `Buffy.DynamicSupervisor`.\n\n  - :throttle (`non_neg_integer`) - Required. The amount of time to wait before invoking the function. This value is in milliseconds.","ref":"Buffy.Throttle.html#module-options"},{"type":"behaviour","title":"Using with Horde - Buffy.Throttle","doc":"If you are running Elixir in a cluster, you can utilize `Horde` to only run one of your throttled functions at a time. To do this, you'll need to set the `:registry_module` and `:supervisor_module` options to `Horde.Registry` and `Horde.DynamicSupervisor` respectively. You'll also need to set the `:registry_name` and `:supervisor_name` options to the name of the Horde registry and dynamic supervisor you want to use.\n\n      defmodule MyThrottler do\n        use Buffy.Throttle,\n          registry_module: Horde.Registry,\n          registry_name: MyApp.HordeRegistry,\n          supervisor_module: Horde.DynamicSupervisor,\n          supervisor_name: MyApp.HordeDynamicSupervisor,\n          throttle: :timer.minutes(2)\n\n        def handle_throttle(args) do\n          # Do something with args\n        end\n      end","ref":"Buffy.Throttle.html#module-using-with-horde"},{"type":"behaviour","title":"Telemetry - Buffy.Throttle","doc":"These are the events that are called by the `Buffy.Throttle` module:\n\n- `[:buffy, :throttle, :throttle]` - Emitted when the `throttle/1` function is called.\n- `[:buffy, :throttle, :handle, :start]` - Emitted at the start of the `handle_throttle/1` function.\n- `[:buffy, :throttle, :handle, :stop]` - Emitted at the end of the `handle_throttle/1` function.\n- `[:buffy, :throttle, :handle, :exception]` - Emitted when an error is raised in the `handle_throttle/1` function.\n\nAll of these events will have the following metadata:\n\n- `:args` - The arguments passed to the `throttle/1` function.\n- `:key` - A hash of the passed arguments used to deduplicate the throttled function.\n- `:module` - The module using `Buffy.Throttle`.\n\nWith the additional metadata for `[:buffy, :throttle, :handle, :stop]`:\n\n- `:result` - The return value of the `handle_throttle/1` function.","ref":"Buffy.Throttle.html#module-telemetry"},{"type":"callback","title":"Buffy.Throttle.handle_throttle/1","doc":"The function called after the throttle has completed. This function will\nreceive the arguments passed to the `throttle/1` function.","ref":"Buffy.Throttle.html#c:handle_throttle/1"},{"type":"callback","title":"Buffy.Throttle.throttle/1","doc":"A function to call the throttle. This will start\nand wait the configured `throttle` time before calling the `c:handle_throttle/1`\nfunction.","ref":"Buffy.Throttle.html#c:throttle/1"},{"type":"type","title":"Buffy.Throttle.args/0","doc":"A list of arbitrary arguments that are used for the `c:handle_throttle/1`\nfunction.","ref":"Buffy.Throttle.html#t:args/0"},{"type":"type","title":"Buffy.Throttle.key/0","doc":"A unique key for debouncing. This is used for GenServer uniqueness and is\ngenerated from hashing all of the args.","ref":"Buffy.Throttle.html#t:key/0"},{"type":"type","title":"Buffy.Throttle.state/0","doc":"Internal state that `Buffy.Throttle` keeps.","ref":"Buffy.Throttle.html#t:state/0"},{"type":"extras","title":"Buffy","doc":"# Buffy\n\nBuffy is a small library of Elixir modules to assist in throttling and debouncing function calling.","ref":"readme.html"},{"type":"extras","title":"Roadmap - Buffy","doc":"- [ ] Allow limiting concurrency of running tasks\n- [ ] Create a debounce module\n- [X] Telemetry instrumentation","ref":"readme.html#roadmap"},{"type":"extras","title":"Installation - Buffy","doc":"Just add [`buffy`](https://hex.pm/packages/buffy) to your `mix.exs` file like so:\n\n \n```elixir\ndef deps do\n  [\n    {:buffy, \"~> 2.0.1\"}\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Published Documentation - Buffy","doc":"Documentation is automatically generated and published to [HexDocs](https://hexdocs.pm/buffy/readme.html) on new releases.","ref":"readme.html#published-documentation"},{"type":"extras","title":"Changelog","doc":"# Changelog\n\n## [2.0.1](https://github.com/stordco/buffy/compare/v2.0.0...v2.0.1) (2023-10-03)\n\n\n#","ref":"changelog.html"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Update callback to match spec ([#21](https://github.com/stordco/buffy/issues/21)) ([5902653](https://github.com/stordco/buffy/commit/59026530d3daf561e209d441b3b98dd1634b2aaa))\n\n## [2.0.0](https://github.com/stordco/buffy/compare/v1.2.2...v2.0.0) (2023-10-02)\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"⚠ BREAKING CHANGES - Changelog","doc":"* `Buffy.Throttle.throttle/1` will now return `:ok` instead of `{:ok, pid}`\n\n#","ref":"changelog.html#breaking-changes"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Return :ok for already started throttle processes ([#20](https://github.com/stordco/buffy/issues/20)) ([07909be](https://github.com/stordco/buffy/commit/07909be0e65c3afb088b6d356862c597912ea157))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Remove old publish workflow ([#15](https://github.com/stordco/buffy/issues/15)) ([4b10fec](https://github.com/stordco/buffy/commit/4b10fec5cf76a4ff3e28a153bf91d126d203cfee))\n* Sync files with stordco/common-config-elixir ([#18](https://github.com/stordco/buffy/issues/18)) ([bfe20fd](https://github.com/stordco/buffy/commit/bfe20fd470e7c70963e3770bf14f744f35843300))\n* Sync files with stordco/common-config-elixir ([#19](https://github.com/stordco/buffy/issues/19)) ([7395018](https://github.com/stordco/buffy/commit/73950186902771e381165b253ab41c94730b8362))\n* Update Hex Link in README.md ([#17](https://github.com/stordco/buffy/issues/17)) ([68927c6](https://github.com/stordco/buffy/commit/68927c6b8f42fa4e6a21c0323592c10bfeb7f8e2))\n\n## [1.2.2](https://github.com/stordco/buffy/compare/v1.2.1...v1.2.2) (2023-09-26)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Do not double supervise throttle module ([#13](https://github.com/stordco/buffy/issues/13)) ([ce046ba](https://github.com/stordco/buffy/commit/ce046bab47f6a622aad586af59f9caf061c99e28))\n* Ensure to always hash binary version of args ([#14](https://github.com/stordco/buffy/issues/14)) ([6216805](https://github.com/stordco/buffy/commit/6216805da569a90e42b2b40693934e3a3d7abbc9))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Sync files with stordco/common-config-elixir ([#10](https://github.com/stordco/buffy/issues/10)) ([930fabe](https://github.com/stordco/buffy/commit/930fabef4d0815cfe144893091537d3405a12629))\n* Sync files with stordco/common-config-elixir ([#12](https://github.com/stordco/buffy/issues/12)) ([7d190da](https://github.com/stordco/buffy/commit/7d190da93eaaf2be765f0b6a31ff9c419f51a06e))\n\n## [1.2.1](https://github.com/stordco/buffy/compare/v1.2.0...v1.2.1) (2023-08-24)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Make buffy public ([#8](https://github.com/stordco/buffy/issues/8)) ([d1eb14f](https://github.com/stordco/buffy/commit/d1eb14fde266b97cf2e84d65914d568e73d827b8))\n\n## [1.2.0](https://github.com/stordco/buffy/compare/v1.1.0...v1.2.0) (2023-08-24)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Features - Changelog","doc":"* Add telemetry to the throttle module ([#7](https://github.com/stordco/buffy/issues/7)) ([74539d8](https://github.com/stordco/buffy/commit/74539d86ea41c531d4743ad57f614fd0f359679e))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Add MIT license ([#5](https://github.com/stordco/buffy/issues/5)) ([fc4306a](https://github.com/stordco/buffy/commit/fc4306afb90b301860f549afe8950bf96aff9f62))\n* Sync files with stordco/common-config-elixir ([#3](https://github.com/stordco/buffy/issues/3)) ([d8bdce2](https://github.com/stordco/buffy/commit/d8bdce2a9114885c8993e45d5b80df8008dc84a4))\n* Update README ([#6](https://github.com/stordco/buffy/issues/6)) ([a874e46](https://github.com/stordco/buffy/commit/a874e46bcb35fe6ed7244e6d831ec8d620fa35ad))\n\n## [1.1.0](https://github.com/stordco/buffy/compare/v1.0.0...v1.1.0) (2023-07-13)\n\n\n#","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"Features - Changelog","doc":"* Make types and logic flow more clear ([7c57e46](https://github.com/stordco/buffy/commit/7c57e46d12941bbc4b79a7b01f7e40f948cd8d13))\n* Setup basic elixir repository ([785b3b8](https://github.com/stordco/buffy/commit/785b3b8b158668ecc40a3437d992abe500a1883d))\n* Simplify first module usage ([b13c522](https://github.com/stordco/buffy/commit/b13c52230116abad7bb258317e4bf260f8706a6f))\n\n\n#","ref":"changelog.html#features"},{"type":"extras","title":"Bug Fixes - Changelog","doc":"* Update release please version ([33aa3c3](https://github.com/stordco/buffy/commit/33aa3c34139fe0669ee53c12b1f5467df4359270))\n* Update test stream data to only run 500 times ([5a423ad](https://github.com/stordco/buffy/commit/5a423ad3324c83809a4c1758bcbd300c4d56fd04))\n* Update test timeout to account for large CI runs ([535c739](https://github.com/stordco/buffy/commit/535c7392df9b74c95ef448177f9106aeb85fdc25))\n\n\n#","ref":"changelog.html#bug-fixes"},{"type":"extras","title":"Miscellaneous - Changelog","doc":"* Remove credo debug file ([1f1419b](https://github.com/stordco/buffy/commit/1f1419b5eccbfdef46f10c6c421f34c9505e72e4))\n* Rename debounce module to throttle ([73d0cf5](https://github.com/stordco/buffy/commit/73d0cf58ea24f6769af6db46d6f62929cc7ab1ae))\n* Sync files with stordco/common-config-elixir ([#2](https://github.com/stordco/buffy/issues/2)) ([c6e4f34](https://github.com/stordco/buffy/commit/c6e4f3465475bd7bbe7571a76a963dd5c74dba3a))\n* Update Buffy.Throttle moduledoc ([c906c43](https://github.com/stordco/buffy/commit/c906c43c1d783cb8175d11f47d21e961a647812a))","ref":"changelog.html#miscellaneous"},{"type":"extras","title":"LICENSE","doc":"The MIT License (MIT)\n\nCopyright (c) 2023-present STORD, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy of this software and associated documentation files (the \"Software\"), to deal in the Software without restriction, including without limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies of the Software, and to permit persons to whom the Software is furnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.","ref":"license.html"}],"content_type":"text/markdown"}